@@ -1,4 +1,5 @@
 from enum import StrEnum
+from maleo.types.string import ListOfStrings
 
 
 class ErrorType(StrEnum):
@@ -15,6 +16,10 @@ class ErrorType(StrEnum):
     BAD_GATEWAY = "server.bad_gateway"
     SERVICE_UNAVAILABLE = "server.service_unavailable"
 
+    @classmethod
+    def choices(cls) -> ListOfStrings:
+        return [e.value for e in cls]
+
 
 class Code(StrEnum):
     BAD_REQUEST = "MAL-ERR-CLI-BDR-001"
@@ -29,3 +34,7 @@ class Code(StrEnum):
     NOT_IMPLEMENTED = "MAL-ERR-SRV-NIM-001"
     BAD_GATEWAY = "MAL-ERR-SRV-BDG-001"
     SERVICE_UNAVAILABLE = "MAL-ERR-SRV-SUN-001"
+
+    @classmethod
+    def choices(cls) -> ListOfStrings:
+        return [e.value for e in cls]
