@@ -1,7 +1,7 @@
 from pydantic import BaseModel, Field
 from typing import Generic, Literal, Type, TypeVar, Union, overload
 from typing_extensions import Annotated
-from maleo.mixins.general import StatusCode
+from ..mixins.general import StatusCode
 from .enums import ErrorType as ErrorTypeEnum
 from .enums import Code as ErrorCode
 
