@@ -2,9 +2,10 @@ import traceback as tb
 from fastapi.responses import JSONResponse
 from typing import Any, Generic, Literal, Optional, Type, Union, overload
 from uuid import uuid4
-from ..contexts.request import RequestContext, OptionalRequestContext
-from ..contexts.response import ResponseContext
-from ..contexts.service import ServiceContext
+from maleo.types.string import ListOfStrings, OptionalString
+from maleo.types.uuid import OptionalUUID
+from ..application import ApplicationContext, OptionalApplicationContext
+from ..connection import ConnectionContext, OptionalConnectionContext
 from ..error.enums import Code as ErrorCode
 from ..error.metadata import ErrorMetadata
 from ..error import (
@@ -27,9 +28,10 @@ from ..operation.action.resource import (
     AnyResourceOperationAction,
 )
 from ..operation.action.system import SystemOperationAction
+from ..operation.action.websocket import WebSocketOperationAction
 from ..operation.context import Context
 from ..operation.enums import OperationType
-from ..operation.mixins import Timestamp
+from ..operation.mixins import Timestamp, OptionalTimestamp
 from ..operation.request import (
     CreateFailedRequestOperation,
     ReadFailedRequestOperation,
@@ -45,6 +47,7 @@ from ..operation.resource import (
     FailedFactory as FailedResourceOperationFactory,
 )
 from ..operation.system import FailedSystemOperation
+from ..operation.websocket import FailedWebSocketOperation
 from ..resource import Resource, OptionalResource
 from ..response import (
     BadRequestResponse,
@@ -61,12 +64,11 @@ from ..response import (
     ServiceUnavailableResponse,
     AnyErrorResponse,
     ErrorResponseT,
+    ResponseContext,
 )
-from maleo.security.authentication import OptionalAnyAuthenticationT
-from maleo.security.authorization import OptionalAuthorizationT
-from maleo.security.impersonation import OptionalImpersonation
-from maleo.types.string import ListOfStrings, OptionalString
-from maleo.types.uuid import OptionalUUID
+from ..security.authentication import OptionalAnyAuthenticationT
+from ..security.authorization import OptionalAuthorizationT
+from ..security.impersonation import OptionalImpersonation
 
 
 class MaleoException(
@@ -87,13 +89,13 @@ class MaleoException(
         *args: object,
         details: Any = None,
         operation_type: Literal[OperationType.REQUEST],
-        service_context: Optional[ServiceContext] = None,
+        application_context: OptionalApplicationContext = None,
         operation_id: OptionalUUID = None,
         operation_context: Context,
         operation_action: AnyResourceOperationAction,
-        operation_timestamp: Optional[Timestamp] = None,
+        operation_timestamp: OptionalTimestamp = None,
         operation_summary: OptionalString = None,
-        request_context: RequestContext,
+        connection_context: ConnectionContext,
         authentication: OptionalAnyAuthenticationT = None,
         authorization: OptionalAuthorizationT = None,
         impersonation: OptionalImpersonation = None,
@@ -105,14 +107,14 @@ class MaleoException(
         *args: object,
         details: Any = None,
         operation_type: Literal[OperationType.RESOURCE],
-        service_context: Optional[ServiceContext] = None,
+        application_context: OptionalApplicationContext = None,
         operation_id: OptionalUUID = None,
         operation_context: Context,
         operation_action: AnyResourceOperationAction,
         resource: Resource,
-        operation_timestamp: Optional[Timestamp] = None,
+        operation_timestamp: OptionalTimestamp = None,
         operation_summary: OptionalString = None,
-        request_context: OptionalRequestContext = None,
+        connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthenticationT = None,
         authorization: OptionalAuthorizationT = None,
         impersonation: OptionalImpersonation = None,
@@ -124,14 +126,14 @@ class MaleoException(
         *args: object,
         details: Any = None,
         operation_type: Literal[OperationType.REQUEST, OperationType.RESOURCE],
-        service_context: Optional[ServiceContext] = None,
+        application_context: OptionalApplicationContext = None,
         operation_id: OptionalUUID = None,
         operation_context: Context,
         operation_action: AnyResourceOperationAction,
         resource: OptionalResource = None,
-        operation_timestamp: Optional[Timestamp] = None,
+        operation_timestamp: OptionalTimestamp = None,
         operation_summary: OptionalString = None,
-        request_context: OptionalRequestContext = None,
+        connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthenticationT = None,
         authorization: OptionalAuthorizationT = None,
         impersonation: OptionalImpersonation = None,
@@ -143,13 +145,31 @@ class MaleoException(
         *args: object,
         details: Any = None,
         operation_type: Literal[OperationType.SYSTEM],
-        service_context: Optional[ServiceContext] = None,
+        application_context: OptionalApplicationContext = None,
         operation_id: OptionalUUID = None,
         operation_context: Context,
         operation_action: SystemOperationAction,
-        operation_timestamp: Optional[Timestamp] = None,
+        operation_timestamp: OptionalTimestamp = None,
         operation_summary: OptionalString = None,
-        request_context: OptionalRequestContext = None,
+        connection_context: OptionalConnectionContext = None,
+        authentication: OptionalAnyAuthenticationT = None,
+        authorization: OptionalAuthorizationT = None,
+        impersonation: OptionalImpersonation = None,
+        response: Optional[AnyErrorResponse] = None,
+    ) -> None: ...
+    @overload
+    def __init__(
+        self,
+        *args: object,
+        details: Any = None,
+        operation_type: Literal[OperationType.WEBSOCKET],
+        application_context: OptionalApplicationContext = None,
+        operation_id: OptionalUUID = None,
+        operation_context: Context,
+        operation_action: WebSocketOperationAction,
+        operation_timestamp: OptionalTimestamp = None,
+        operation_summary: OptionalString = None,
+        connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthenticationT = None,
         authorization: OptionalAuthorizationT = None,
         impersonation: OptionalImpersonation = None,
@@ -161,14 +181,18 @@ class MaleoException(
         *args: object,
         details: Any = None,
         operation_type: OperationType,
-        service_context: Optional[ServiceContext] = None,
+        application_context: OptionalApplicationContext = None,
         operation_id: OptionalUUID = None,
         operation_context: Context,
-        operation_action: Union[AnyResourceOperationAction, SystemOperationAction],
+        operation_action: Union[
+            AnyResourceOperationAction,
+            SystemOperationAction,
+            WebSocketOperationAction,
+        ],
         resource: OptionalResource = None,
-        operation_timestamp: Optional[Timestamp] = None,
+        operation_timestamp: OptionalTimestamp = None,
         operation_summary: OptionalString = None,
-        request_context: OptionalRequestContext = None,
+        connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthenticationT = None,
         authorization: OptionalAuthorizationT = None,
         impersonation: OptionalImpersonation = None,
@@ -179,14 +203,18 @@ class MaleoException(
         *args: object,
         details: Any = None,
         operation_type: OperationType,
-        service_context: Optional[ServiceContext] = None,
+        application_context: OptionalApplicationContext = None,
         operation_id: OptionalUUID = None,
         operation_context: Context,
-        operation_action: Union[AnyResourceOperationAction, SystemOperationAction],
+        operation_action: Union[
+            AnyResourceOperationAction,
+            SystemOperationAction,
+            WebSocketOperationAction,
+        ],
         resource: OptionalResource = None,
-        operation_timestamp: Optional[Timestamp] = None,
+        operation_timestamp: OptionalTimestamp = None,
         operation_summary: OptionalString = None,
-        request_context: OptionalRequestContext = None,
+        connection_context: OptionalConnectionContext = None,
         authentication: OptionalAnyAuthenticationT = None,
         authorization: OptionalAuthorizationT = None,
         impersonation: OptionalImpersonation = None,
@@ -196,10 +224,10 @@ class MaleoException(
         self.details = details
         self.operation_type = operation_type
 
-        self.service_context = (
-            service_context
-            if service_context is not None
-            else ServiceContext.from_env()
+        self.application_context = (
+            application_context
+            if application_context is not None
+            else ApplicationContext.from_env()
         )
 
         self.operation_id = operation_id if operation_id is not None else uuid4()
@@ -217,7 +245,7 @@ class MaleoException(
             else f"{self.operation_type.capitalize()} operation failed due to exception being raised"
         )
 
-        self.request_context = request_context
+        self.connection_context = connection_context
         self.authentication = authentication
         self.authorization = authorization
         self.impersonation = impersonation
@@ -295,6 +323,12 @@ class MaleoException(
             OptionalAuthorizationT,
             ErrorResponseT,
         ],
+        FailedWebSocketOperation[
+            AnyErrorT,
+            OptionalAnyAuthenticationT,
+            OptionalAuthorizationT,
+            ErrorResponseT,
+        ],
     ]:
         if self.operation_type is OperationType.REQUEST:
             if not isinstance(self.operation_action, ResourceOperationActions):
@@ -302,7 +336,7 @@ class MaleoException(
                     ErrorCode.BAD_REQUEST,
                     f"Invalid operation_action to generate request operation: {type(self.operation_action)}",
                 )
-            if self.request_context is None:
+            if self.connection_context is None:
                 raise ValueError(
                     ErrorCode.BAD_REQUEST,
                     "Failed generating request operation from MaleoException. Request context is not given",
@@ -319,13 +353,13 @@ class MaleoException(
 
             return FailedRequestOperationFactory.generate(
                 self.operation_action,
-                service_context=self.service_context,
+                application_context=self.application_context,
                 id=self.operation_id,
                 context=self.operation_context,
                 timestamp=self.operation_timestamp,
                 summary=self.operation_summary,
                 error=self.error,
-                request_context=self.request_context,
+                connection_context=self.connection_context,
                 authentication=self.authentication,
                 authorization=self.authorization,
                 impersonation=self.impersonation,
@@ -345,13 +379,13 @@ class MaleoException(
                 )
             return FailedResourceOperationFactory.generate(
                 self.operation_action,
-                service_context=self.service_context,
+                application_context=self.application_context,
                 id=self.operation_id,
                 context=self.operation_context,
                 timestamp=self.operation_timestamp,
                 summary=self.operation_summary,
                 error=self.error,
-                request_context=self.request_context,
+                connection_context=self.connection_context,
                 authentication=self.authentication,
                 authorization=self.authorization,
                 impersonation=self.impersonation,
@@ -370,14 +404,39 @@ class MaleoException(
                 OptionalAuthorizationT,
                 ErrorResponseT,
             ](
-                service_context=self.service_context,
+                application_context=self.application_context,
                 id=self.operation_id,
                 context=self.operation_context,
                 action=self.operation_action,
                 timestamp=self.operation_timestamp,
                 summary=self.operation_summary,
                 error=self.error,
-                request_context=self.request_context,
+                connection_context=self.connection_context,
+                authentication=self.authentication,
+                authorization=self.authorization,
+                impersonation=self.impersonation,
+                response=self.response,
+            )
+        elif self.operation_type is OperationType.WEBSOCKET:
+            if not isinstance(self.operation_action, WebSocketOperationAction):
+                raise ValueError(
+                    ErrorCode.BAD_REQUEST,
+                    f"Invalid operation_action to generate websocket operation: {type(self.operation_action)}",
+                )
+            return FailedWebSocketOperation[
+                AnyErrorT,
+                OptionalAnyAuthenticationT,
+                OptionalAuthorizationT,
+                ErrorResponseT,
+            ](
+                application_context=self.application_context,
+                id=self.operation_id,
+                context=self.operation_context,
+                action=self.operation_action,
+                timestamp=self.operation_timestamp,
+                summary=self.operation_summary,
+                error=self.error,
+                connection_context=self.connection_context,
                 authentication=self.authentication,
                 authorization=self.authorization,
                 impersonation=self.impersonation,
@@ -459,6 +518,14 @@ class MaleoException(
     ) -> FailedSystemOperation[
         AnyErrorT, OptionalAnyAuthenticationT, OptionalAuthorizationT, ErrorResponseT
     ]: ...
+    @overload
+    def generate_operation(
+        self,
+        operation_type: Literal[OperationType.WEBSOCKET],
+        /,
+    ) -> FailedWebSocketOperation[
+        AnyErrorT, OptionalAnyAuthenticationT, OptionalAuthorizationT, ErrorResponseT
+    ]: ...
     def generate_operation(
         self,
         operation_type: OperationType,
@@ -518,6 +585,12 @@ class MaleoException(
             OptionalAuthorizationT,
             ErrorResponseT,
         ],
+        FailedWebSocketOperation[
+            AnyErrorT,
+            OptionalAnyAuthenticationT,
+            OptionalAuthorizationT,
+            ErrorResponseT,
+        ],
     ]:
         if operation_type != self.operation_type:
             raise ValueError(
@@ -542,14 +615,39 @@ class MaleoException(
                 OptionalAuthorizationT,
                 ErrorResponseT,
             ](
-                service_context=self.service_context,
+                application_context=self.application_context,
                 id=self.operation_id,
                 context=self.operation_context,
                 action=self.operation_action,
                 timestamp=self.operation_timestamp,
                 summary=self.operation_summary,
                 error=self.error,
-                request_context=self.request_context,
+                connection_context=self.connection_context,
+                authentication=self.authentication,
+                authorization=self.authorization,
+                impersonation=self.impersonation,
+                response=self.response,
+            )
+        elif operation_type is OperationType.WEBSOCKET:
+            if not isinstance(self.operation_action, WebSocketOperationAction):
+                raise ValueError(
+                    ErrorCode.BAD_REQUEST,
+                    f"Invalid operation_action to generate websocket operation: {type(self.operation_action)}",
+                )
+            return FailedWebSocketOperation[
+                AnyErrorT,
+                OptionalAnyAuthenticationT,
+                OptionalAuthorizationT,
+                ErrorResponseT,
+            ](
+                application_context=self.application_context,
+                id=self.operation_id,
+                context=self.operation_context,
+                action=self.operation_action,
+                timestamp=self.operation_timestamp,
+                summary=self.operation_summary,
+                error=self.error,
+                connection_context=self.connection_context,
                 authentication=self.authentication,
                 authorization=self.authorization,
                 impersonation=self.impersonation,
@@ -563,7 +661,7 @@ class MaleoException(
                 )
 
             if operation_type is OperationType.REQUEST:
-                if self.request_context is None:
+                if self.connection_context is None:
                     raise ValueError(
                         ErrorCode.BAD_REQUEST,
                         "Failed generating request operation from MaleoException. Request context is not given",
@@ -580,13 +678,13 @@ class MaleoException(
 
                 return FailedRequestOperationFactory.generate(
                     self.operation_action,
-                    service_context=self.service_context,
+                    application_context=self.application_context,
                     id=self.operation_id,
                     context=self.operation_context,
                     timestamp=self.operation_timestamp,
                     summary=self.operation_summary,
                     error=self.error,
-                    request_context=self.request_context,
+                    connection_context=self.connection_context,
                     authentication=self.authentication,
                     authorization=self.authorization,
                     impersonation=self.impersonation,
@@ -601,13 +699,13 @@ class MaleoException(
                     )
                 return FailedResourceOperationFactory.generate(
                     self.operation_action,
-                    service_context=self.service_context,
+                    application_context=self.application_context,
                     id=self.operation_id,
                     context=self.operation_context,
                     timestamp=self.operation_timestamp,
                     summary=self.operation_summary,
                     error=self.error,
-                    request_context=self.request_context,
+                    connection_context=self.connection_context,
                     authentication=self.authentication,
                     authorization=self.authorization,
                     impersonation=self.impersonation,
@@ -804,3 +902,19 @@ class ServiceUnavailable(
 ):
     error_cls = ServiceUnavailableError
     response_cls = ServiceUnavailableResponse
+
+
+exceptions = (
+    BadRequest,
+    Unauthorized,
+    Forbidden,
+    NotFound,
+    MethodNotAllowed,
+    Conflict,
+    UnprocessableEntity,
+    TooManyRequests,
+    InternalServerError,
+    NotImplemented,
+    BadGateway,
+    ServiceUnavailable,
+)
