@@ -1,7 +1,11 @@
 import logging
 from fastapi import Request, Response, status
 from fastapi.encoders import jsonable_encoder
-from fastapi.exceptions import HTTPException, RequestValidationError
+from fastapi.exceptions import (
+    HTTPException,
+    RequestValidationError,
+    ResponseValidationError,
+)
 from fastapi.requests import HTTPConnection
 from fastapi.responses import JSONResponse
 from pydantic import ValidationError
@@ -34,7 +38,14 @@ def authentication_error_handler(conn: HTTPConnection, exc: AuthenticationError)
 
 
 async def general_exception_handler(request: Request, exc: Exception) -> Response:
-    if isinstance(exc, (RequestValidationError, ValidationError)):
+    if isinstance(
+        exc,
+        (
+            RequestValidationError,
+            ResponseValidationError,
+            ValidationError,
+        ),
+    ):
         return JSONResponse(
             content=UnprocessableEntityResponse(
                 other=jsonable_encoder(exc.errors())
