@@ -1,9 +1,9 @@
 from pydantic import BaseModel, Field
-from typing import Generic, TypeVar
+from typing import Annotated, Generic, TypeVar
 
 
 ActionT = TypeVar("ActionT", bound=BaseModel)
 
 
 class ActionMixin(BaseModel, Generic[ActionT]):
-    action: ActionT = Field(..., description="Action.")
+    action: Annotated[ActionT, Field(..., description="Action.")]
