@@ -2,7 +2,6 @@ import traceback
 from logging import Logger
 from typing import Generic
 from maleo.logging.enums import Level
-from maleo.mixins.general import Success, SuccessT
 from maleo.types.boolean import OptionalBoolean
 from maleo.types.dict import (
     OptionalStringToStringDict,
@@ -13,6 +12,7 @@ from maleo.utils.merger import merge_dicts
 from ..application import ApplicationContextMixin
 from ..connection import OptionalConnectionContextT, ConnectionContextMixin
 from ..error import OptionalAnyErrorT, ErrorMixin
+from ..mixins.general import Success, SuccessT
 from ..resource import OptionalResourceT, ResourceMixin
 from ..response import (
     OptionalResponseContextT,
