@@ -1,7 +1,7 @@
 from fastapi import Request, Header
 from typing import Callable
 from uuid import UUID
-from maleo.enums.request import Header as HeaderEnum
+from maleo.enums.connection import Header as HeaderEnum
 from maleo.types.uuid import OptionalUUID
 from .enums import IdSource
 from .extractor import extract_operation_id
