@@ -1,10 +1,10 @@
 from copy import deepcopy
 from typing import Any, Generic, Literal, Optional, Type, Union, overload
 from uuid import UUID
-from maleo.mixins.general import SuccessT
 from ..application import ApplicationContext
 from ..connection import ConnectionContext
 from ..error import OptionalAnyErrorT, AnyErrorT
+from ..mixins.general import SuccessT
 from ..pagination import OptionalAnyPagination
 from ..response import (
     ResponseContext,
