@@ -1,12 +1,12 @@
 from copy import deepcopy
 from typing import Generic, Literal, Optional, Type, Union, overload
 from uuid import UUID
-from maleo.mixins.general import SuccessT
 from ..application import ApplicationContext
 from ..connection import OptionalConnectionContext
 from ..data import ModelDataT
 from ..error import OptionalAnyErrorT, AnyErrorT
 from ..metadata import ModelMetadataT
+from ..mixins.general import SuccessT
 from ..pagination import PaginationT
 from ..resource import Resource
 from ..response import (
