@@ -1,37 +1,45 @@
-from typing import Generic
-from maleo.mixins.filter import DateFilters
-from maleo.mixins.identity import (
+from pydantic import Field
+from typing import Annotated, Generic
+from maleo.enums.status import ListOfDataStatuses, FULL_DATA_STATUSES
+from .mixins.filter import DateFilters
+from .mixins.identity import (
     IdentifierTypeT,
     IdentifierValueT,
     IdentifierTypeValue,
 )
-from maleo.mixins.parameter import (
+from .mixins.parameter import (
     Search,
     UseCache,
 )
-from maleo.mixins.sort import SortColumns
-from maleo.mixins.status import DataStatuses
+from .mixins.sort import SortColumns
+from .mixins.status import DataStatuses
 from .operation.action.status import StatusUpdateOperationAction
 from .pagination import BaseFlexiblePagination, BaseStrictPagination
 
 
 class ReadSingleParameter(
-    DataStatuses,
+    DataStatuses[ListOfDataStatuses],
     UseCache,
     IdentifierTypeValue[IdentifierTypeT, IdentifierValueT],
     Generic[IdentifierTypeT, IdentifierValueT],
 ):
-    pass
+    statuses: Annotated[
+        ListOfDataStatuses,
+        Field(list(FULL_DATA_STATUSES), description="Data statuses", min_length=1),
+    ] = list(FULL_DATA_STATUSES)
 
 
 class BaseReadMultipleParameter(
     SortColumns,
     Search,
-    DataStatuses,
+    DataStatuses[ListOfDataStatuses],
     DateFilters,
     UseCache,
 ):
-    pass
+    statuses: Annotated[
+        ListOfDataStatuses,
+        Field(list(FULL_DATA_STATUSES), description="Data statuses", min_length=1),
+    ] = list(FULL_DATA_STATUSES)
 
 
 class ReadUnpaginatedMultipleParameter(
