@@ -13,7 +13,6 @@ from typing import (
     Union,
     overload,
 )
-from maleo.mixins.general import SuccessT, Success, CodeT, Descriptor
 from maleo.types.dict import StringToAnyDict
 from maleo.types.string import OptionalString
 from .data import DataPair, AnyDataT, ModelDataT
@@ -34,6 +33,7 @@ from .error.descriptor import (
 )
 from .error.enums import Code as ErrorCode
 from .metadata import AnyMetadataT, ModelMetadataT
+from .mixins.general import SuccessT, Success, CodeT, Descriptor
 from .pagination import OptionalPaginationT, PaginationT
 from .payload import (
     Payload,
