@@ -1,4 +1,5 @@
 from enum import StrEnum
+from maleo.types.string import ListOfStrings
 
 
 class Code(StrEnum):
@@ -16,3 +17,7 @@ class Code(StrEnum):
     UPDATE_MULTIPLE_DATA = "MAL-SCS-MTD-004"
     DELETE_MULTIPLE_DATA = "MAL-SCS-MTD-005"
     OPTIONAL_MULTIPLE_DATA = "MAL-SCS-OMD-001"
+
+    @classmethod
+    def choices(cls) -> ListOfStrings:
+        return [e.value for e in cls]
